@@ -73,6 +73,12 @@ void CameraUI::ProcessCropAndSend(QImage img, QPoint topLeft, bool correctVignet
     connect(destCBox, SIGNAL(currentIndexChanged(int)), this, SLOT(CropChanged()));
 }
 
+void CameraUI::QuitApp(){
+    overlay->disable();
+    ::close(overlay->overlay_fd);
+    qApp->quit();
+}
+
 // Populates the language combo box cb
 void CameraUI::PopulateLangCBox(QComboBox* cb){
     cb->clear();
@@ -243,6 +249,7 @@ void CameraUI::SetTranslationText(QString text){
     statusLabel->setText("- Done -");
     translatedText = text;
     translateView->setText(text);
+    viewText();
 }
 
 void CameraUI::SetResegText(QString text){
