@@ -187,10 +187,8 @@ int main(int argc, char **argv) {
     QObject::connect(bbView, SIGNAL(clicked()), cameraUI, SLOT(StartResegmentDialog()));
 
     // Hook up the buttons
-    QObject::connect(quitButton, SIGNAL(clicked()), 
-                     cameraThread, SLOT(stop()));
-    QObject::connect(quitButton, SIGNAL(clicked()),
-                     qApp, SLOT(quit()));
+    QObject::connect(quitButton, SIGNAL(clicked()), cameraThread, SLOT(stop()));
+    //QObject::connect(quitButton, SIGNAL(clicked()), qApp, SLOT(quit()));
     QObject::connect(photoButton, SIGNAL(clicked()),
                      cameraUI, SLOT(ViewPhoto()));
     QObject::connect(sendButton, SIGNAL(clicked()),
